import { useState } from "react";

const initialItems = [
  { id: 1, description: "Passports", quantity: 2, packed: false },
  { id: 2, description: "Socks", quantity: 12, packed: false },
  { id: 3, description: "Charger", quantity: 1, packed: false },
  { id: 4, description: "Boarding Pass", quantity: 5, packed: true },
];


function App() {
  const [items,setItems]=useState([])

  function handleAddItem(item){
    
    //This function will be invoked by Form Component on Click of Add
   setItems((items)=>[...items,item]);
    console.log(items);
  }
  function handleDeleteItem(id){
    //This function invoked by Item Component
    //App => PackageList ==> Item
    setItems((item)=> items.filter(item=>item.id!=id))

  }
  return (
    <div className="app">
      
      <Logo />
      <Form onAddItems={handleAddItem} />
      <PackagingList items={items} onDeleteItem={handleDeleteItem}/>
      <Stats />
    </div>
  );
}


function Logo(){
  return <h1>🏝️ Travel Guide App 🧳  </h1>;
}

function Form({onAddItems}){
  const [description,setDescription]=useState("");
  const[quantity,setQuantity]=useState(1);
  function handleSubmit(e){
    e.preventDefault();
   
    const newItem={description,quantity,packed:false,id:Date.now()}
    onAddItems(newItem);
    //Setting Default Values
    setDescription("");
    setQuantity(1);
    }
    
  
  return <form className="add-form" onSubmit={handleSubmit}>
    
    <h3>What Do you need for your 😂 Trip</h3>

    <select value={quantity} onChange={(e)=>setQuantity(e.target.value)}>

  {Array.from({length:20},(_,i) => i+1) .map
    (
      num=> <option value={num} key={num}>{num}</option>
    )

  }
    </select>

    <input type="text" placeholder="Item .... " value={description}
    onChange={(e)=>setDescription(e.target.value)} />
    <button>Add</button>

    </form>
  
}


function PackagingList({items,onDeleteItem}){
  return (
  <div className="list">  
  <ul>

    {items.map((item) => (<Item item={item} onDeleteItem={onDeleteItem} key={item.id} /> ))}
  </ul>
  </div>
  )
}

function Item({item,onDeleteItem}){
  return <li>
    <span style={item.packed ? {textDecoration:'line-through'} : {}} >
    {item.quantity}  
    {item.description}
    <button onClick={()=>onDeleteItem(item.id)}>❌</button>
    </span>
  </li>
}

function Stats(){
  return <footer className="stats"> 💼  You have X Items in your List , and You already Packed X (x%) </footer>
}
export default App;
